@@ -9,6 +9,8 @@ from .diagonal_coulomb_hamiltonian import DiagonalCoulombHamiltonian
 from .interaction_operator import (
     InteractionOperator,
     InteractionOperatorError,
+    get_tensors_from_integrals,
+    get_active_space_integrals,
 )
 
 from .interaction_rdm import (
@@ -21,3 +23,4 @@ from .quadratic_hamiltonian import (
     QuadraticHamiltonianError,
     antisymmetric_canonical_form,
 )
+from .doci_hamiltonian import DOCIHamiltonian
